.. title: ReSTful underline in Nikola
.. slug: restful-underline
.. date: 2015-08-24 12:02:51+02:00
.. tags: web,python
.. category: 
.. link: 
.. description: 
.. type: text

Sometimes you want to underline something. ``*italics*`` bzw. ``<em>italics</em>`` just switches to an italics iversion of your font. You can fix that with CSS; but what if you want both?

This is how to do it in my blog system (`Nikola <http://getnikola.com>`_):

.. TEASER_END

* in ``plugins/under.plugin``:

  .. code-block::
  
    [Core]
    name = rest_under
    module = under
    
    [Nikola]
    compiler = rest
    plugincategory = CompilerExtension
    
    [Documentation]
    author = Matthias Urlichs
    version = 0.1
    website = https://matthias.urlichs.de/
    description = UnderLine the marked text
   
* in ``plugins/under.py``:

  .. code-block:: python
  
    # -*- coding: utf-8 -*-
  
    # Copyright © 2015 Matthias Urlichs
    
    """reST role for underlining."""
    
    from docutils import nodes
    from docutils.parsers.rst import roles
    
    from nikola.plugin_categories import RestExtension
    
    class Plugin(RestExtension):
    
        """Plugin for doc role."""
    
        name = 'rest_under'
    
        def set_site(self, site):
            """Set Nikola site."""
            roles.register_canonical_role('u', under_role)
            return super(Plugin, self).set_site(site)
    
    
    def under_role(name, rawtext, text, lineno, inliner,
                 options={}, content=[]):
        """Generate a underline-class emphasis."""
        options = dict(**options)
        options['classes'] = ['underline']
        return [nodes.emphasis(rawtext, text, *content, **options)],[]
   
* in ``files/assets/css/custom.css``:

  .. code-block:: css

     em.underline { font-style: normal; text-decoration: underline; }

* … et voilà, you can now :u:`underline`.

  .. code-block:: rest

     … et voilà, you can now :u:`underline`.

You're welcome.
